"""This module provides tools to convert a ASP format to SIF or MIDAS format


"""

__all__ = ["ASPnet2SIF"]


class ASPnet2SIF(object):
    """Converts ASP format to SIF format"""
    def __init__(self, filename):
        """.. rubric:: constructor

        :param str filename:

        """
        self.filename = filename[:]
        self.data = None
        self._reset()
        self._readnet()

    def _readnet(self):
        """read NET file

        format is ::

            A -> B +
            A -> B -

        """
        self.net = []
        try:
            f = open(self.filename, 'r')
            data = f.read().split("\n")
            for row in data:
                if len(row)>0:
                    self.net.append(row)
                else:
                    print("warning. found an empty line")
        except IOError, e:
            raise IOError(e)
        else:
            # if the file was opened, let us close it.
            f.close()

    def convert(self):
        """Convert the NET data into SIF data"""
        self._reset()
        for row in self.net:
            LHS, RHS = row.split("->")
            self.nodes1.append(LHS.strip())
            self.nodes2.append(RHS.split()[0].strip())
            
            sign = RHS.split()[1].strip()
            if sign == "+":
                self.signs.append("1")
            elif sign == "-":
                self.signs.append("-1")
            else:
                raise ValueError("found a sign differnt from + or - sign. Check your input NET file")

    def write2sif(self, filename):
        """Write SIF reactions into a file"""
        if len(self.nodes1)>0:
            h = open(filename, "w")
            for n1,n2,s in zip(self.nodes1, self.nodes2, self.signs):
                h.write("%s\t%s\t%s\n" % (n1, s,n2))
            h.close()
        else:
            print("nothing to save. Is the SIF file correct ?") 

    def _reset(self):
        self.nodes1 = []
        self.nodes2 = []
        self.signs = []

    def __str__(self):
        txt = ""
        for n1,n2,s in zip(self.nodes1, self.nodes2, self.signs):
            txt += "%s -> %s %s" % (n1, n2, s)
        return txt

