"""Module to convert MIDAS file format into OBS format used in ASP

OBS files are used to check sign consistency within ASP. The output format is::

    specy = +
    specy = -

specy can be repeated.


"""

__all__ = ["MIDAS2ASPobs"]




class MIDAS2ASPobs(object):
    """Reads MIDAS file and save into observations


    This is a simple and naive implementation. See :meth:`convert` for details.
    A future version will use cellnopt.asp for more versatile convertions.

    """
    def __init__(self, filename):
        """.. rubric:: constructor


        :param str filemame:


        """
        self.filename = filename[:]
        self.inputs = None
        self._reset()
        self._readMIDAS()

    def _readMIDAS(self):
        """

        """
        from cellnopt.core import MIDASReader
        self.midas = MIDASReader(self.filename)

        data = open(self.filename, "r").read()
        data = data.strip().split("\n")
        self.header = [(i, x) for i, x in enumerate(data[0].split(","))]
        self.DV = [(x[0], x[1].strip()) for x in self.header if x[1].startswith("DV:")]
        self.DA = [(x[0], x[1].strip()) for x in self.header if x[1].startswith("DA:")]

        # get rid of the header
        self.data = data[1:] # get rid of the header
        # convert read data (string) into float
        self.data = [[y for y in x.split(',')] for x in self.data]

    def convert(self, timeIndex=1):
        """Simple conversion to OBS format

        For now, the sign is based on the value of the data. 

        If data is positive, sign is +. Otherwise, it is set to -.

        THis may not be what is requested. Instead, we may want to focus 
        on the fact that data increases or increases at a given time as compared
        to time zero.
        """
        self._reset()
        # ignore the data with time set to 0

        for index,name in enumerate(self.midas.cnolist.namesSignals):
            values = self.midas.cnolist.valueSignals[timeIndex][:,index]
            for v in values:
                if v == 'NA':
                    pass
                else:
                    v = float(v)
                    self.species.append(name)
                    if v>=0:
                        self.signs.append("+")
                    else:
                        self.signs.append("-")

    def _reset(self):
        self.species = []
        self.signs = []

    def __str__(self):
        txt = ""
        for n1,s in zip(self.species, self.signs):
            txt += "%s = %s" % (n1, s)
        return txt

    def write2obs(self, filename):
        """Write nodes and signs into a OBS format

        ASP OBS format is of the form::

            A = +
            A = -

        """
        if len(self.species)>0:
            h = open(filename, "w")
            for n1,s in zip(self.species, self.signs):
                h.write("%s = %s\n" % (n1, s))
            h.close()
        else:
            print("nothing to save. Is the MIDAS file correct ?") 
